@@ -58,7 +58,7 @@ void Yukon::initialize()
 
     for ( int i = 0; i < 4; ++i )
     {
-        target[i] = new PatPile( this, i + 1, QString("target%1").arg(i) );
+        target[i] = new PatPile( this, i + 1, QStringLiteral("target%1").arg(i) );
         target[i]->setPileRole(PatPile::Foundation);
         target[i]->setLayoutPos(0.11+7*dist_x, dist_y *i);
         target[i]->setKeyboardSelectHint( KCardPile::NeverFocus );
@@ -67,7 +67,7 @@ void Yukon::initialize()
 
     for ( int i = 0; i < 7; ++i )
     {
-        store[i] = new PatPile( this, 5 + i, QString("store%1").arg(i) );
+        store[i] = new PatPile( this, 5 + i, QStringLiteral("store%1").arg(i) );
         store[i]->setPileRole(PatPile::Tableau);
         store[i]->setLayoutPos(dist_x*i, 0);
         store[i]->setAutoTurnTop(true);
